@@ -6,6 +6,7 @@
 import time
 import random, uuid
 import datetime
+from datetime import datetime, timedelta
 from aishu.datafaker.profession.entity import date
 
 class ParaDateFiledServer(object):
@@ -96,6 +97,45 @@ class ParaDateFiledServer(object):
     def getToTime(self):
         return 0 if not date.ToTime_List else date.ToTime_List[0]
 
+    def getUtcStartTime(self):
+        year_1 = str(int(time.strftime("%Y", time.localtime())) - 1)
+        year_2 = str(int(time.strftime("%Y", time.localtime())) - 2)
+        year_3 = str(int(time.strftime("%Y", time.localtime())) - 3)
+        year_4 = str(int(time.strftime("%Y", time.localtime())) - 4)
+        year_5 = str(int(time.strftime("%Y", time.localtime())) - 5)
+        time_list = [year_1, year_2, year_3, year_4, year_5]
+        info = {
+            'year': random.choice(time_list),
+            'month': time.strftime("%m", time.localtime()),
+            'day': time.strftime("%d", time.localtime()),
+            'hour': time.strftime("%H", time.localtime()),
+            'minute': time.strftime("%M", time.localtime()),
+            'second': time.strftime("%S", time.localtime()),
+        }
+        ut_time = info['year'] + '-' + info['month'] + '-' + info['day'] + ' ' + info['hour'] + ':' + info['minute'] + ':' + info['second']
+        bj_time = datetime.strptime(ut_time, "%Y-%m-%d %H:%M:%S") - timedelta(hours=8)
+        bj_time_info = str(bj_time).split(' ')
+        bj_time_year = str(bj_time_info[0]).split('-')
+        bj_time_host = str(bj_time_info[1]).split(':')
+
+        return bj_time_year[0] + '-' + bj_time_year[1] + '-' + bj_time_year[2] + 'T' + bj_time_host[0] + ':' + bj_time_host[1] + ':' + bj_time_host[2] + '.000Z'
+
+    def getUtcEndTime(self):
+        info = {
+            'year': time.strftime("%Y", time.localtime()),
+            'month': time.strftime("%m", time.localtime()),
+            'day': time.strftime("%d", time.localtime()),
+            'hour': time.strftime("%H", time.localtime()),
+            'minute': time.strftime("%M", time.localtime()),
+            'second': time.strftime("%S", time.localtime()),
+        }
+        ut_time = info['year'] + '-' + info['month'] + '-' + info['day'] + ' ' + info['hour'] + ':' + info['minute'] + ':' + info['second']
+        bj_time = datetime.strptime(ut_time, "%Y-%m-%d %H:%M:%S") - timedelta(hours=8)
+        bj_time_info = str(bj_time).split(' ')
+        bj_time_year = str(bj_time_info[0]).split('-')
+        bj_time_host = str(bj_time_info[1]).split(':')
+        return bj_time_year[0] + '-' + bj_time_year[1] + '-' + bj_time_year[2] + 'T' + bj_time_host[0] + ':' + bj_time_host[1] + ':' + bj_time_host[2] + '.000Z'
+
     def getStartDate(self):
         startdate = time.strftime("%Y-%m-%d %H:%M:%S", time.localtime())
         return startdate
